Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(530)

Unified Diff: components/policy/core/common/async_policy_provider.h

Issue 1130753002: [components/policy] Use ThreadTaskRunnerHandle instead of LoopProxy (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/policy/core/common/async_policy_provider.h
diff --git a/components/policy/core/common/async_policy_provider.h b/components/policy/core/common/async_policy_provider.h
index 63e33865e9c2c061ed9f7422d9fef30525b8f1ee..f2e63687beb943ec823edc33555c44c4dcd9ab94 100644
--- a/components/policy/core/common/async_policy_provider.h
+++ b/components/policy/core/common/async_policy_provider.h
@@ -14,7 +14,7 @@
#include "components/policy/policy_export.h"
namespace base {
-class MessageLoopProxy;
+class SingleThreadTaskRunner;
}
namespace policy {
@@ -50,11 +50,12 @@ class POLICY_EXPORT AsyncPolicyProvider : public ConfigurationPolicyProvider,
// Callback passed to the loader that it uses to pass back the current policy
// bundle to the provider. This is invoked on the background thread and
// forwards to OnLoaderReloaded() on the loop that owns the provider,
// if |weak_this| is still valid.
- static void LoaderUpdateCallback(scoped_refptr<base::MessageLoopProxy> loop,
- base::WeakPtr<AsyncPolicyProvider> weak_this,
- scoped_ptr<PolicyBundle> bundle);
+ static void LoaderUpdateCallback(
+ scoped_refptr<base::SingleThreadTaskRunner> runner,
+ base::WeakPtr<AsyncPolicyProvider> weak_this,
+ scoped_ptr<PolicyBundle> bundle);
// The |loader_| that does the platform-specific policy loading. It lives
// on the background thread but is owned by |this|.
« no previous file with comments | « components/policy/core/browser/url_blacklist_manager.cc ('k') | components/policy/core/common/async_policy_provider.cc » ('j') | no next file with comments »
@@ -50,11 +50,12 @@ class POLICY_EXPORT AsyncPolicyProvider : public ConfigurationPolicyProvider,
// Callback passed to the loader that it uses to pass back the current policy
// bundle to the provider. This is invoked on the background thread and
- // forwards to OnLoaderReloaded() on the loop that owns the provider,
+ // forwards to OnLoaderReloaded() on the runner that owns the provider,
// if |weak_this| is still valid.

Powered by Google App Engine
This is Rietveld 408576698